@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,9 +24,7 @@
 
 /* Don't translate any string defined in this header */
 
-#define LITERAL(s) #s
-#define STRINGIFY(s) LITERAL(s)
-const QString PGM_VERSION(STRINGIFY(VERSION));
+const QString PGM_VERSION(QT_STRINGIFY(VERSION));
 
 const QString BLD_DATE(__DATE__);
 const QString BLD_TIME(__TIME__);
@@ -40,10 +38,11 @@ const QString CMP_VERSION("MSVC " + QString::number(_MSC_VER/100.0f,'f',2));
 const QString CMP_VERSION(QString());
 #endif
 
-const QString QSTR_APPNAME("VMPK-Virtual MIDI Piano Keyboard");
+const QString QSTR_APPNAME("VMPK");
 const QString QSTR_DOMAIN("vmpk.sourceforge.net");
 const QString QSTR_VMPKPX("vmpk_");
 const QString QSTR_QTPX("qt_");
+const QString QSTR_DRUMSTICKPX("drumstick-widgets_");
 
 const QString QSTR_WINDOW("Window");
 const QString QSTR_GEOMETRY("Geometry");
@@ -78,7 +77,6 @@ const QString QSTR_CONTROLLER("Controller");
 const QString QSTR_GRABKB("GrabKeyboard");
 const QString QSTR_STYLEDKNOBS("StyledKnobs");
 const QString QSTR_ALWAYSONTOP("AlwaysOnTop");
-const QString QSTR_SHOWNOTENAMES("ShowNoteNames");
 const QString QSTR_SHOWSTATUSBAR("ShowStatusBar");
 const QString QSTR_RAWKEYBOARDMODE("RawKeyboardMode");
 const QString QSTR_EXTRACONTROLLERS("ExtraControllers");
@@ -102,7 +100,17 @@ const QString QSTR_MULTICAST_ADDRESS("225.0.0.37");
 const QString QSTR_PALETTEPREFIX("Palette_");
 const QString QSTR_CURRENTPALETTE("CurrentPalette");
 const QString QSTR_SHOWCOLORSCALE("ShowColorScale");
-const QString QSTR_CHKBOXSTYLE("QCheckBox::indicator {width: 20px; height: 20px;} QCheckBox::indicator:checked {image: url(:/vpiano/led_green.svg);} QCheckBox::indicator:unchecked{image: url(:/vpiano/led_grey.svg);}");
+const QString QSTR_CHKBOXSTYLE("QCheckBox::indicator {width: 20px; height: 20px; background: none;} QCheckBox::indicator:checked {image: url(:/vpiano/led_green.png);} QCheckBox::indicator:unchecked{image: url(:/vpiano/led_grey.png);}");
+const QString QSTR_DEFAULTFONT("Helvetica, 50");
+const QString QSTR_WINSNAP("StickyWindowSnapping");
+const QString QSTR_DARKMODE("ForcedDarkMode");
+const QString QSTR_STYLE("QtStyle");
+
+#if defined(Q_OS_WINDOWS)
+const QString DEFAULTSTYLE("fusion");
+#else
+const QString DEFAULTSTYLE;
+#endif
 
 #if defined(SMALL_SCREEN)
 const QString QSTR_VMPKURL("http://vmpk.sourceforge.net/m/");
@@ -126,7 +134,6 @@ const int MIDIVELOCITY = 100;
 const int MIDIPAN = 64;
 const int MIDIVOLUME = 100;
 const int MIDIMAXVALUE = 127;
-const int DEFAULTSTARTINGKEY = 0;
 const int DEFAULTBASEOCTAVE = 3;
 
 #if defined(SMALL_SCREEN)
@@ -134,19 +141,10 @@ const int DEFAULTNUMBEROFKEYS = 25;
 const int TOOLBARLABELMARGIN = 2;
 const int KEYLABELFONTSIZE = 3;
 #else
-const int DEFAULTNUMBEROFKEYS = 61;
 const int TOOLBARLABELMARGIN = 5;
-const int KEYLABELFONTSIZE = 7;
 #endif
 const int NETWORKPORTNUMBER = 21928;
 
-const int PAL_SINGLE = 0;
-const int PAL_DOUBLE = 1;
-const int PAL_CHANNELS = 2;
-const int PAL_SCALE = 3;
-
-#if defined(Q_WS_MAC) && defined(QT_MAC_USE_COCOA)
-#error "This program requires Qt built with the Carbon framework. Sorry."
-#endif
+const int RESTART_VMPK = 42;
 
 #endif /*CONSTANTS_H_*/
