@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,58 +16,80 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "keyboardmap.h"
-
-#include <QDebug>
 #include <QFile>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 #include <QKeySequence>
 #include <QMessageBox>
+#include "keyboardmap.h"
 
-void KeyboardMap::loadFromXMLFile(const QString fileName)
+void VMPKKeyboardMap::setFileName(const QString fileName)
+{
+    m_fileName = fileName;
+}
+
+const QString& VMPKKeyboardMap::getFileName() const
+{
+    return m_fileName;
+}
+
+void VMPKKeyboardMap::setRawMode(bool b)
+{
+    m_rawMode = b;
+}
+
+bool VMPKKeyboardMap::getRawMode() const
+{
+    return m_rawMode;
+}
+
+void VMPKKeyboardMap::loadFromXMLFile(const QString fileName)
 {
     QFile f(fileName);
     if (f.open(QFile::ReadOnly | QFile::Text)) {
         m_fileName = fileName;
         initializeFromXML(&f);
         f.close();
-        qDebug() << "Loaded Map: " << fileName;
+        //qDebug() << "Loaded Map: " << fileName << "count:" << count() << "rawmode:" << m_rawMode;
     }
     if (f.error() != QFile::NoError) {
         reportError(fileName, tr("Error loading a file"), f.errorString());
     }
 }
 
-void KeyboardMap::saveToXMLFile(const QString fileName)
+void VMPKKeyboardMap::saveToXMLFile(const QString fileName)
 {
     QFile f(fileName);
     if (f.open(QFile::WriteOnly | QFile::Text)) {
         serializeToXML(&f);
         f.close();
         m_fileName = fileName;
-        qDebug() << "Saved Map: " << fileName;
+        //qDebug() << "Saved Map: " << fileName;
     }
     if (f.error() != QFile::NoError) {
         reportError(fileName, tr("Error saving a file"), f.errorString());
     }
 }
 
-void KeyboardMap::initializeFromXML(QIODevice *dev)
+void VMPKKeyboardMap::initializeFromXML(QIODevice *dev)
 {
     QXmlStreamReader reader(dev);
     clear();
     while (!reader.atEnd()) {
         reader.readNext();
+        if (reader.isDTD()) {
+            //qDebug() << "DTD:" << reader.dtdName();
+            m_rawMode = (reader.dtdName() == QStringLiteral("rawkeyboardmap"));
+        } else
         if (reader.isStartElement()) {
-            if (reader.name() == (m_rawMode?"rawkeymap":"keyboardmap")) {
+            if (reader.name() == (m_rawMode?QStringLiteral("rawkeymap"):QStringLiteral("keyboardmap"))) {
                 reader.readNext();
                 while (reader.isWhitespace() || reader.isComment()) {
                     //qDebug() << "1st. junk place" << reader.text();
                     reader.readNext();
                 }
                 while (reader.isStartElement()) {
-                    if (reader.name() == "mapping") {
+                    if (reader.name() == QStringLiteral("mapping")) {
                         QString key = reader.attributes().value(m_rawMode?"keycode":"key").toString();
                         QString sn = reader.attributes().value("note").toString();
                         bool ok = false;
@@ -98,11 +120,10 @@ void KeyboardMap::initializeFromXML(QIODevice *dev)
     }
 }
 
-void KeyboardMap::serializeToXML(QIODevice *dev)
+void VMPKKeyboardMap::serializeToXML(QIODevice *dev)
 {
     QXmlStreamWriter writer(dev);
     writer.setAutoFormatting(true);
-    //writer.setCodec("UTF-8");
     writer.writeStartDocument();
     writer.writeDTD(m_rawMode?"<!DOCTYPE rawkeyboardmap>":"<!DOCTYPE keyboardmap>");
     writer.writeStartElement(m_rawMode ? "rawkeymap" : "keyboardmap");
@@ -121,19 +142,33 @@ void KeyboardMap::serializeToXML(QIODevice *dev)
     writer.writeEndDocument();
 }
 
-void KeyboardMap::copyFrom(const KeyboardMap* other)
+void VMPKKeyboardMap::copyFrom(const VMPKKeyboardMap* other)
 {
-    m_fileName = other->getFileName();
-    m_rawMode = other->getRawMode();
-    clear();
-    KeyboardMap::ConstIterator it;
-    for(it = other->begin(); it != other->end(); ++it)
-        insert(it.key(), it.value());
+    if (other != this) {
+        m_fileName = other->getFileName();
+        m_rawMode = other->getRawMode();
+        clear();
+        VMPKKeyboardMap::ConstIterator it;
+        for(it = other->begin(); it != other->end(); ++it)
+            insert(it.key(), it.value());
+    }
 }
 
-void KeyboardMap::reportError( const QString filename,
+void VMPKKeyboardMap::copyFrom(const drumstick::widgets::KeyboardMap* other, bool rawMode)
+{
+    if (other != this) {
+        m_fileName = QSTR_DEFAULT;
+        m_rawMode = rawMode;
+        clear();
+        drumstick::widgets::KeyboardMap::ConstIterator it;
+        for(it = other->begin(); it != other->end(); ++it)
+            insert(it.key(), it.value());
+    }
+}
+
+void VMPKKeyboardMap::reportError( const QString filename,
                                const QString title,
                                const QString err )
 {
-    QMessageBox::warning(0, title, tr("File: %1\n%2").arg(filename).arg(err));
+    QMessageBox::warning(nullptr, title, tr("File: %1\n%2").arg(filename, err));
 }
