@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,25 +19,29 @@
 #ifndef KEYBOARDMAP_H
 #define KEYBOARDMAP_H
 
-#include "constants.h"
 #include <QHash>
 #include <QIODevice>
+#include <drumstick/pianokeybd.h>
+#include "constants.h"
 
-class KeyboardMap : public QHash<int, int>
+class VMPKKeyboardMap : public drumstick::widgets::KeyboardMap
 {
     Q_DECLARE_TR_FUNCTIONS(KeyboardMap)
 public:
-    KeyboardMap() : QHash<int, int>(), m_fileName(QSTR_DEFAULT), m_rawMode(false) {}
+    VMPKKeyboardMap() : QHash<int, int>(), m_fileName(QSTR_DEFAULT), m_rawMode(false)
+    { }
+
     void loadFromXMLFile(const QString fileName);
     void saveToXMLFile(const QString fileName);
     void initializeFromXML(QIODevice *dev);
 	void serializeToXML(QIODevice *dev);
-	void copyFrom(const KeyboardMap* other);
+    void copyFrom(const VMPKKeyboardMap* other);
+    void copyFrom(const drumstick::widgets::KeyboardMap* other, bool rawMode);
 
-	void setFileName(const QString fileName) { m_fileName = fileName; }
-	const QString& getFileName() const { return m_fileName; }
-	void setRawMode(bool b) { m_rawMode = b; }
-	bool getRawMode() const { return m_rawMode; }
+    void setFileName(const QString fileName);
+    const QString& getFileName() const;
+    void setRawMode(bool b);
+    bool getRawMode() const;
 
 private:
     void reportError( const QString filename, const QString title, const QString err );
