@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,13 +16,14 @@
     with this program; If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "kmapdialog.h"
-#include "vpiano.h"
 #include <QFileInfo>
 #include <QHeaderView>
 #include <QPushButton>
 #include <QKeySequence>
 #include <QFileDialog>
+#include <drumstick/pianokeybd.h>
+#include "kmapdialog.h"
+#include "vpianosettings.h"
 
 KMapDialog::KMapDialog(QWidget *parent)
     : QDialog(parent)
@@ -36,10 +37,10 @@ KMapDialog::KMapDialog(QWidget *parent)
     connect(m_btnSave, SIGNAL(clicked()), SLOT(slotSave()));
 }
 
-void KMapDialog::displayMap(const KeyboardMap* map)
+void KMapDialog::displayMap(const VMPKKeyboardMap* map)
 {
     int row;
-    if (map != NULL) m_map.copyFrom(map);
+    if (map != nullptr) m_map.copyFrom(map);
     setWindowTitle(m_map.getRawMode() ? tr("Raw Key Map Editor") : tr("Key Map Editor"));
     ui.tableWidget->clearContents();
     ui.tableWidget->setHorizontalHeaderItem(0, new QTableWidgetItem(m_map.getRawMode() ? tr("Key Code") : tr("Key")));
@@ -64,7 +65,7 @@ void KMapDialog::updateMap()
     QTableWidgetItem* item;
     for( int i=0; i<128; ++i) {
         item = ui.tableWidget->item(i, 0);
-        if ((item != NULL) && !item->text().isEmpty()) {
+        if ((item != nullptr) && !item->text().isEmpty()) {
             if (m_map.getRawMode()) {
                 int keycode = item->text().toInt(&ok);
                 if (ok) m_map.insert(keycode, i);
@@ -76,7 +77,7 @@ void KMapDialog::updateMap()
     }
 }
 
-void KMapDialog::getMap(KeyboardMap* map)
+void KMapDialog::getMap(VMPKKeyboardMap* map)
 {
     updateMap();
     map->copyFrom(&m_map);
@@ -84,14 +85,14 @@ void KMapDialog::getMap(KeyboardMap* map)
 
 void KMapDialog::slotOpen()
 {
-    QString fileName = QFileDialog::getOpenFileName(0,
+    QString fileName = QFileDialog::getOpenFileName(nullptr,
                                 tr("Open keyboard map definition"),
-                                VPiano::dataDirectory(),
+                                VPianoSettings::dataDirectory(),
                                 tr("Keyboard map (*.xml)"));
     if (!fileName.isEmpty()) {
         m_map.clear();
         m_map.loadFromXMLFile(fileName);
-        displayMap(NULL);
+        displayMap(nullptr);
     }
 }
 
@@ -99,7 +100,7 @@ void KMapDialog::slotSave()
 {
     QFileDialog dlg(this);
     dlg.setNameFilter(tr("Keyboard map (*.xml)"));
-    dlg.setDirectory(VPiano::dataDirectory());
+    dlg.setDirectory(VPianoSettings::dataDirectory());
     dlg.setWindowTitle(tr("Save keyboard map definition"));
     dlg.setDefaultSuffix("xml");
     dlg.setFileMode(QFileDialog::AnyFile);
