@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ class Riff : public QObject
     Q_OBJECT
 
 public:
-    Riff(QObject* parent = 0);
+    Riff(QObject* parent = nullptr);
     virtual ~Riff();
     void readFromFile(QString fileName);
     void readFromStream(QDataStream* ds);
