@@ -1,7 +1,7 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
-    Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -56,13 +56,13 @@ class ShortcutTableItemEdit : public QLineEdit
 public:
 
 	// Constructor.
-	ShortcutTableItemEdit(QWidget *pParent = NULL)
+	ShortcutTableItemEdit(QWidget *pParent = nullptr)
 		: QLineEdit(pParent) {}
 
 protected:
 
 	// Shortcut key to text event translation.
-	void keyPressEvent(QKeyEvent *pKeyEvent)
+    void keyPressEvent(QKeyEvent *pKeyEvent) override
 	{
 		int iKey = pKeyEvent->key();
 		Qt::KeyboardModifiers modifiers = pKeyEvent->modifiers();
@@ -103,7 +103,7 @@ ShortcutTableItemEditor::ShortcutTableItemEditor (
 
 	QHBoxLayout *pLayout = new QHBoxLayout();
 	pLayout->setSpacing(0);
-	pLayout->setMargin(0);
+    pLayout->setContentsMargins(0,0,0,0);
 	pLayout->addWidget(m_pLineEdit);
 	pLayout->addWidget(m_pToolButton);
 	QWidget::setLayout(pLayout);
